locale = {
--      [":("] = "",
--      ["!!!"] = "",
--      ["..."] = "",
--      ["011101000"] = "", -- A_Classic_Fairytale:dragon
--      ["011101001"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:family, A_Classic_Fairytale:journey, A_Classic_Fairytale:queen, A_Classic_Fairytale:shadow, A_Classic_Fairytale:united
      ["30 minutes later..."] = "30 minutos mais tarde...", -- A_Classic_Fairytale:shadow
      ["About a month ago, a cyborg came and told us that you're the cannibals!"] = "Há cerca de um mês, um ciborgue veio e nos contou que vocês são os canibais!", -- A_Classic_Fairytale:enemy
      ["Accuracy Bonus!"] = "Bônus por acurácia",
      ["Ace"] = "Ás", -- User_Mission_-_RCPlane_Challenge, User_Mission_-_Rope_Knock_Challenge
      ["Achievement Unlocked"] = "Conquista alcançada", -- User_Mission_-_Bamboo_Thicket, User_Mission_-_That_Sinking_Feeling, Tumbler
      ["A Classic Fairytale"] = "Um conto de fadas clássico", -- A_Classic_Fairytale:first_blood
--      ["???"] = "", -- A_Classic_Fairytale:backstab
      ["Actually, you aren't worthy of life! Take this..."] = "Na verdade, você não merece viver! Tome isso...", -- A_Classic_Fairytale:shadow
      ["A cy-what?"] = "Um cib... o quê?", -- A_Classic_Fairytale:enemy
--      ["Adventurous"] = "", -- A_Classic_Fairytale:journey
      ["Africa"] = "África", -- Continental_supplies
      ["After Leaks A Lot betrayed his tribe, he joined the cannibals..."] = "Depois que Vaza Demais traiu sua tribo, ele se juntou aos canibais...", -- A_Classic_Fairytale:first_blood
--      ["After the shock caused by the enemy spy, Leaks A Lot and Dense Cloud went hunting to relax."] = "", -- A_Classic_Fairytale:shadow
--      ["Again with the 'cannibals' thing!"] = "", -- A_Classic_Fairytale:enemy
      ["a Hedgewars challenge"] = "um desafio Hedgewars", -- User_Mission_-_RCPlane_Challenge, User_Mission_-_Rope_Knock_Challenge
      ["a Hedgewars mini-game"] = "um mini-jogo Hedgewars", -- Space_Invasion, The_Specialists
	["Aiming Practice"] = "Pratique a sua pontaria", --Bazooka, Shotgun, SniperRifle
--      ["A leap in a leap"] = "", -- A_Classic_Fairytale:first_blood
      ["A little gift from the cyborgs"] = "Um pequeno presente dos ciborgues", -- A_Classic_Fairytale:shadow
--      ["All gone...everything!"] = "", -- A_Classic_Fairytale:enemy
--      ["All right, we just need to get to the other side of the island!"] = "", -- A_Classic_Fairytale:journey
--      ["All walls touched!"] = "", -- WxW
--      ["Ammo"] = "",
--      ["Ammo Depleted!"] = "",
--      ["ammo extended!"] = "",
--      ["Ammo is reset at the end of your turn."] = "",
--      ["Ammo Maniac!"] = "",
--      ["And how am I alive?!"] = "", -- A_Classic_Fairytale:enemy
      ["And so happenned that Leaks A Lot failed to complete the challenge! He landed, pressured by shame..."] = "E acabou que Vaza Demais falhou em superar o desafio! Ele chegou em terra firme, pressionado pela vergonha...", -- A_Classic_Fairytale:first_blood
      ["And so it began..."] = "E foi assim que começou...", -- A_Classic_Fairytale:first_blood
--      ["...and so the cyborgs took over the world..."] = "", -- A_Classic_Fairytale:shadow
--      ["And so they discovered that cyborgs weren't invulnerable..."] = "", -- A_Classic_Fairytale:journey
--      ["And where's all the weed?"] = "", -- A_Classic_Fairytale:dragon
--      ["And you believed me? Oh, god, that's cute!"] = "", -- A_Classic_Fairytale:journey
--      ["Anno 1032: [The explosion will make a strong push ~ wide range, wont affect hogs close to the target]"] = "", -- Continental_supplies
--      ["Antarctica"] = "", -- Continental_supplies
--      ["Are we there yet?"] = "", -- A_Classic_Fairytale:shadow
--      ["Are you accusing me of something?"] = "", -- A_Classic_Fairytale:backstab
--      ["Are you saying that many of us have died for your entertainment?"] = "", -- A_Classic_Fairytale:enemy
--      ["Artur Detour"] = "", -- A_Classic_Fairytale:queen
--      ["As a reward for your performance, here's some new technology!"] = "", -- A_Classic_Fairytale:dragon
--      ["a shoppa minigame"] = "", -- WxW
--      ["Asia"] = "", -- Continental_supplies
--      ["Assault Team"] = "", -- A_Classic_Fairytale:backstab
--      ["As the ammo is sparse, you might want to reuse ropes while mid-air.|"] = "", -- A_Classic_Fairytale:dragon
      ["As the challenge was completed, Leaks A Lot set foot on the ground..."] = "Como o desafio foi superado, Vaza Demais colocou os pés no chão...", -- A_Classic_Fairytale:first_blood
--      ["As you can see, there is no way to get on the other side!"] = "", -- A_Classic_Fairytale:dragon
--      ["Attack From Rope"] = "", -- WxW
--      ["Australia"] = "", -- Continental_supplies
--      ["Available points remaining: "] = "",
--      ["Back Breaker"] = "", -- A_Classic_Fairytale:backstab
--      ["Back in the village, after telling the villagers about the threat..."] = "", -- A_Classic_Fairytale:united
--      ["[Backspace]"] = "",
--      ["Backstab"] = "", -- A_Classic_Fairytale:backstab
--      ["Bad Team"] = "", -- User_Mission_-_The_Great_Escape
--      ["Bamboo Thicket"] = "",
--      ["Barrel Eater!"] = "",
--      ["Barrel Launcher"] = "",
--      ["Baseballbat"] = "", -- Continental_supplies
	["Bat balls at your enemies and|push them into the sea!"] = "Rebata as bolas em direção ao seus|e derrube-os no mar!",
	["Bat your opponents through the|baskets and out of the map!"] = "Rebata seus oponentes para|fora do mapa através dos cestos!",
	["Bazooka Training"] = "Treino com a Bazuca",
--      ["Beep Loopers"] = "", -- A_Classic_Fairytale:queen
	["Best laps per team: "] = "Melhor volta por equipe: ",
--      ["Best Team Times: "] = "",
--      ["Beware, though! If you are slow, you die!"] = "", -- A_Classic_Fairytale:dragon
--      ["Biomechanic Team"] = "", -- A_Classic_Fairytale:family
--      ["Blender"] = "", -- A_Classic_Fairytale:family
--      ["Bloodpie"] = "", -- A_Classic_Fairytale:backstab
--      ["Bloodrocutor"] = "", -- A_Classic_Fairytale:shadow
--      ["Bloodsucker"] = "", -- A_Classic_Fairytale:shadow
--      ["Bloody Rookies"] = "", -- 01#Boot_Camp, User_Mission_-_Dangerous_Ducklings, User_Mission_-_Diver, User_Mission_-_Spooky_Tree
--      ["Bone Jackson"] = "", -- A_Classic_Fairytale:backstab
--      ["Bonely"] = "", -- A_Classic_Fairytale:shadow
--      ["Boom!"] = "",
--      ["BOOM!"] = "",
--      ["Boss defeated!"] = "",
--      ["Boss Slayer!"] = "",
--      ["Brain Blower"] = "", -- A_Classic_Fairytale:journey
--      ["Brainiac"] = "", -- A_Classic_Fairytale:epil, A_Classic_Fairytale:first_blood, A_Classic_Fairytale:shadow
--      ["Brainila"] = "", -- A_Classic_Fairytale:united
--      ["Brain Stu"] = "", -- A_Classic_Fairytale:united
--      ["Brain Teaser"] = "", -- A_Classic_Fairytale:backstab
--      ["Brutal Lily"] = "", -- A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil
--      ["Brutus"] = "", -- A_Classic_Fairytale:backstab
--      ["Build a track and race."] = "",
--      ["Bullseye"] = "", -- A_Classic_Fairytale:dragon
--      ["But it proved to be no easy task!"] = "", -- A_Classic_Fairytale:dragon
--      ["But that's impossible!"] = "", -- A_Classic_Fairytale:backstab
--      ["But the ones alive are stronger in their heart!"] = "", -- A_Classic_Fairytale:enemy
--      ["But...we died!"] = "", -- A_Classic_Fairytale:backstab
--      ["But where can we go?"] = "", -- A_Classic_Fairytale:united
--      ["But why would they help us?"] = "", -- A_Classic_Fairytale:backstab
--      ["But you're cannibals. It's what you do."] = "", -- A_Classic_Fairytale:enemy
--      ["But you said you'd let her go!"] = "", -- A_Classic_Fairytale:journey
--      ["Call me Beep! Well, 'cause I'm such a nice...person!"] = "", -- A_Classic_Fairytale:family
      ["Cannibals"] = "Canibais", -- A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:first_blood
--      ["Cannibal Sentry"] = "", -- A_Classic_Fairytale:journey
--      ["Cannibals?! You're the cannibals!"] = "", -- A_Classic_Fairytale:enemy
--      ["CAPTURE THE FLAG"] = "",
--      ["Careless"] = "",
--      ["Carol"] = "", -- A_Classic_Fairytale:family
--      ["CHALLENGE COMPLETE"] = "", -- User_Mission_-_RCPlane_Challenge
--      ["Change Weapon"] = "",
--      ["Choose your side! If you want to join the strange man, walk up to him.|Otherwise, walk away from him. If you decide to att...nevermind..."] = "", -- A_Classic_Fairytale:shadow
--      ["Clumsy"] = "",
--      ["Cluster Bomb MASTER!"] = "", -- Basic_Training_-_Cluster_Bomb
--      ["Cluster Bomb Training"] = "", -- Basic_Training_-_Cluster_Bomb
--      ["Codename: Teamwork"] = "",
--      ["Collateral Damage"] = "", -- A_Classic_Fairytale:journey
--      ["Collateral Damage II"] = "", -- A_Classic_Fairytale:journey
      ["Collect all the crates, but remember, our time in this life is limited!"] = "Colete todas as caixas, mas lembre-se: nosso tempo nesta vida é limitado!", -- A_Classic_Fairytale:first_blood
--      ["Collect or destroy all the health crates."] = "", -- User_Mission_-_RCPlane_Challenge
      ["Collect the crate on the right.|Hint: Select the rope, [Up] or [Down] to aim, [Space] to fire, directional keys to move.|Ropes can be fired again in the air!"] = "Pegue a caixa à direita.|Dica: Selecione a corda, [Cima] ou [Baixo] para mirar, [Espaço] para atirar, teclas direcionais para se mover.|Cordas podem ser disparadas novamente no ar!", -- A_Classic_Fairytale:first_blood
      ["Collect the crates within the time limit!|If you fail, you'll have to try again."] = "Colete as caixas dentro do limite de tempo!|Se falhar, você terá que tentar de novo.", -- A_Classic_Fairytale:first_blood
      ["Come closer, so that your training may continue!"] = "Aproxime-se, para que seu treinamento possa continuar!", -- A_Classic_Fairytale:first_blood
--      ["Compete to use as few planes as possible!"] = "", -- User_Mission_-_RCPlane_Challenge
--      ["Complete the track as fast as you can!"] = "",
--      ["COMPLETION TIME"] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["Configuration accepted."] = "", -- WxW
--      ["Congratulations!"] = "",
--      ["Congratulations"] = "", -- Basic_Training_-_Rope
--      ["Congratulations! You needed only half of time|to eliminate all targets."] = "", -- Basic_Training_-_Cluster_Bomb
--      ["Congratulations! You've completed the Rope tutorial! |- Tutorial ends in 10 seconds!"] = "", -- Basic_Training_-_Rope
	["Congratulations! You've eliminated all targets|within the allowed time frame."] = "Parabéns! Você eliminou todos os alvos|dentro do tempo limite.", --Bazooka, Shotgun, SniperRifle
--      ["Continental supplies"] = "", -- Continental_supplies
--      ["Control pillars to score points."] = "",
--      ["Corporationals"] = "", -- A_Classic_Fairytale:queen
--      ["Corpsemonger"] = "", -- A_Classic_Fairytale:shadow
--      ["Corpse Thrower"] = "", -- A_Classic_Fairytale:epil
--      ["Crates Left:"] = "", -- User_Mission_-_RCPlane_Challenge
--      ["Cybernetic Empire"] = "",
--      ["Cyborg. It's what the aliens call themselves."] = "", -- A_Classic_Fairytale:enemy
--      ["Dahmer"] = "", -- A_Classic_Fairytale:backstab
--      ["DAMMIT, ROOKIE!"] = "",
--      ["DAMMIT, ROOKIE! GET OFF MY HEAD!"] = "",
--      ["Dangerous Ducklings"] = "",
--      ["Deadweight"] = "",
--      ["Defeat the cannibals"] = "", -- A_Classic_Fairytale:backstab
--      ["Defeat the cannibals!|"] = "", -- A_Classic_Fairytale:united
--      ["Defeat the cannibals!|Grenade hint: set the timer with [1-5], aim with [Up]/[Down] and hold [Space] to set power"] = "", -- A_Classic_Fairytale:shadow
--      ["Defeat the cyborgs!"] = "", -- A_Classic_Fairytale:enemy
--      ["Defend yourself!|Hint: You can get tips on using weapons by moving your mouse over them in the weapon selection menu"] = "", -- A_Classic_Fairytale:shadow
--      ["Demolition is fun!"] = "",
--      ["Dense Cloud"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:journey, A_Classic_Fairytale:queen, A_Classic_Fairytale:shadow, A_Classic_Fairytale:united
--      ["Dense Cloud must have already told them everything..."] = "", -- A_Classic_Fairytale:shadow
--      ["Depleted Kamikaze!"] = "",
      ["Destroy him, Leaks A Lot! He is responsible for the deaths of many of us!"] = "Destrua-o, Vaza Demais! Ele é responsável pelas mortes de muitos de nós!", -- A_Classic_Fairytale:first_blood
      ["Destroy invaders to score points."] = "Destrua os invasores para conseguir pontos.",
      ["Destroy the targets!|Hint: Select the Shoryuken and hit [Space]|P.S. You can use it mid-air."] = "Destrua os alvos!|Dica: Selecione o Shoryuken e aperte [Espaço]|Obs.: Você pode usá-lo em pleno ar.", -- A_Classic_Fairytale:first_blood
      ["Destroy the targets!|Hint: [Up], [Down] to aim, [Space] to shoot"] = "Destrua os alvos!|Dica: [Cima], [Baixo] para mirar, [Espaço] para atirar", -- A_Classic_Fairytale:first_blood
--      ["Did anyone follow you?"] = "", -- A_Classic_Fairytale:united
--      ["Did you see him coming?"] = "", -- A_Classic_Fairytale:shadow
--      ["Did you warn the village?"] = "", -- A_Classic_Fairytale:shadow
--      ["Die, die, die!"] = "", -- A_Classic_Fairytale:dragon
--      ["Disguise as a Rockhopper Penguin: [Swap place with a random enemy hog in the circle]"] = "", -- Continental_supplies
--      ["Dist: "] = "", -- Space_Invasion
--      ["Do not laugh, inexperienced one, for he speaks the truth!"] = "", -- A_Classic_Fairytale:backstab
--      ["Do not let his words fool you, young one! He will stab you in the back as soon as you turn away!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Do the deed"] = "", -- A_Classic_Fairytale:first_blood
--      ["Double Kill!"] = "",
--      ["DOUBLE KILL"] = "", -- Mutant
--      ["Do you have any idea how valuable grass is?"] = "", -- A_Classic_Fairytale:enemy
--      ["Do you think you're some kind of god?"] = "", -- A_Classic_Fairytale:enemy
--      ["Dragon's Lair"] = "", -- A_Classic_Fairytale:dragon
--      ["Drills"] = "", -- A_Classic_Fairytale:backstab
--      ["Drone Hunter!"] = "",
--      ["Drop a bomb: [drop some heroic wind that will turn into a bomb on impact]"] = "", -- Continental_supplies
--      ["Drowner"] = "",
--      ["Dude, all the plants are gone!"] = "", -- A_Classic_Fairytale:family
--      ["Dude, can you see Ramon and Spiky?"] = "", -- A_Classic_Fairytale:journey
--      ["Dude, that's so cool!"] = "", -- A_Classic_Fairytale:backstab
--      ["Dude, we really need a new shaman..."] = "", -- A_Classic_Fairytale:shadow
--      ["Dude, what's this place?!"] = "", -- A_Classic_Fairytale:dragon
--      ["Dude, where are we?"] = "", -- A_Classic_Fairytale:backstab
--      ["Dude, wow! I just had the weirdest high!"] = "", -- A_Classic_Fairytale:backstab
--      ["Duration"] = "", -- Continental_supplies
--      ["Dust storm: [Deals 20 damage to all enemies in the circle]"] = "", -- Continental_supplies
--      ["Each turn you get 1-3 random weapons"] = "",
--      ["Each turn you get one random weapon"] = "",
--      ["Eagle Eye"] = "", -- A_Classic_Fairytale:backstab
--      ["Eagle Eye: [Blink to the impact ~ one shot]"] = "", -- Continental_supplies
--      ["Ear Sniffer"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:epil
--      ["Elderbot"] = "", -- A_Classic_Fairytale:family
--      ["Elimate your captor."] = "", -- User_Mission_-_The_Great_Escape
--      ["Eliminate all enemies"] = "",
	["Eliminate all targets before your time runs out.|You have unlimited ammo for this mission."] = "Destrua todos os alvos antes que o tempo acabe.|Você tem munição infinita para esta missão.", --Bazooka, Shotgun, SniperRifle
--      ["Eliminate enemy hogs and take their weapons."] = "", -- Highlander
--      ["Eliminate Poison before the time runs out"] = "",
--      ["Eliminate the Blue Team"] = "",
--      ["Eliminate the enemy before the time runs out"] = "", -- User_Mission_-_Bamboo_Thicket, User_Mission_-_Newton_and_the_Hammock
--      ["Eliminate the enemy hogs to win."] = "",
--      ["Eliminate the enemy specialists."] = "",
--      ["- Eliminate Unit 3378 |- Feeble Resistance must survive"] = "",
--      ["Elmo"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
--      ["Energetic Engineer"] = "",
--      ["Enjoy the swim..."] = "",
--      ["[Enter]"] = "",
--      ["Europe"] = "", -- Continental_supplies
--      [" ever done to you?!"] = "", -- A_Classic_Fairytale:backstab
--      ["Everyone knows this."] = "", -- A_Classic_Fairytale:enemy
--      ["Every single time!"] = "", -- A_Classic_Fairytale:dragon
--      ["Everything looks OK..."] = "", -- A_Classic_Fairytale:enemy
--      ["Exactly, man! That was my dream."] = "", -- A_Classic_Fairytale:backstab
--      ["Eye Chewer"] = "", -- A_Classic_Fairytale:journey
--      ["INSANITY"] = "", -- Mutant
--      ["Family Reunion"] = "", -- A_Classic_Fairytale:family
	["Fastest lap: "] = "Volta mais rápida: ",
--      ["Feeble Resistance"] = "",
--      ["Fell From Grace"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
--      ["Fell From Heaven"] = "", -- A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:first_blood, A_Classic_Fairytale:journey, A_Classic_Fairytale:queen
--      ["Fell From Heaven is the best! Fell From Heaven is the greatest!"] = "", -- A_Classic_Fairytale:family
--      ["Femur Lover"] = "", -- A_Classic_Fairytale:shadow
--      ["Fierce Competition!"] = "", -- Space_Invasion
--      ["Fiery Water"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:queen, A_Classic_Fairytale:united
--      ["Find your tribe!|Cross the lake!"] = "", -- A_Classic_Fairytale:dragon
--      ["Finish your training|Hint: Animations can be skipped with the [Precise] key."] = "", -- A_Classic_Fairytale:first_blood
--      ["Fire"] = "",
--      ["Fire a mine: [Does what it says ~ Cant be dropped close to an enemy ~ 1 sec]"] = "", -- Continental_supplies
--      ["First aid kits?!"] = "", -- A_Classic_Fairytale:united
      ["First Blood"] = "Primeiro sangue", -- A_Classic_Fairytale:first_blood
--      ["FIRST BLOOD MUTATES"] = "", -- Mutant
      ["First Steps"] = "Primeiros passos", -- A_Classic_Fairytale:first_blood
      ["Flag captured!"] = "Bandeira capturada!",
--      ["Flag respawned!"] = "",
--      ["Flag returned!"] = "",
--      ["Flags, and their home base will be placed where each team ends their first turn."] = "",
--      ["Flamer"] = "",
--      ["Flaming Worm"] = "", -- A_Classic_Fairytale:backstab
--      ["Flare: [fire up some bombs depending on hogs depending on hogs in the circle"] = "", -- Continental_supplies
--      ["Flesh for Brainz"] = "", -- A_Classic_Fairytale:journey
--      ["For improved features/stability, play 0.9.18+"] = "", -- WxW
--      ["Free Dense Cloud and continue the mission!"] = "", -- A_Classic_Fairytale:journey
--      ["Friendly Fire!"] = "",
--      ["fuel extended!"] = "",
--      ["GAME BEGUN!!!"] = "",
--      ["Game Modifiers: "] = "",
--      ["GAME OVER!"] = "",
--      ["Game Started!"] = "",
--      ["Game? Was this a game to you?!"] = "", -- A_Classic_Fairytale:enemy
--      ["GasBomb"] = "", -- Continental_supplies
--      ["Gas Gargler"] = "", -- A_Classic_Fairytale:queen
--      ["Get Dense Cloud out of the pit!"] = "", -- A_Classic_Fairytale:journey
--      ["Get on over there and take him out!"] = "",
--      ["Get on the head of the mole"] = "", -- A_Classic_Fairytale:first_blood
--      ["Get out of there!"] = "", -- User_Mission_-_The_Great_Escape
--      ["Get that crate!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Get the crate on the other side of the island!|"] = "", -- A_Classic_Fairytale:journey
--      ["Get to the target using your rope! |Controls: Left & Right to swing the rope - Up & Down to Contract and Expand!"] = "", -- Basic_Training_-_Rope
--      ["Get your teammates out of their natural prison and save the princess!|Hint: Drilling holes should solve everything.|Hint: It might be a good idea to place a girder before starting to drill. Just saying.|Hint: All your hedgehogs need to be above the marked height!|Hint: Leaks A Lot needs to get really close to the princess!"] = "", -- A_Classic_Fairytale:family
--      ["GG!"] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["Gimme Bones"] = "", -- A_Classic_Fairytale:backstab
--      ["Glark"] = "", -- A_Classic_Fairytale:shadow
--      ["Goal"] = "",
--      ["GO! GO! GO!"] = "",
--      ["Good birdy......"] = "",
--      ["Good Dude"] = "", -- User_Mission_-_The_Great_Escape
--      ["Good idea, they'll never find us there!"] = "", -- A_Classic_Fairytale:united
--      ["Good luck...or else!"] = "", -- A_Classic_Fairytale:journey
--      ["Good luck out there!"] = "",
--      ["Good so far!"] = "",
--      ["Good to go!"] = "",
--      ["Go on top of the flower"] = "", -- A_Classic_Fairytale:first_blood
--      ["Go, quick!"] = "", -- A_Classic_Fairytale:backstab
--      ["Gorkij"] = "", -- A_Classic_Fairytale:journey
--      ["Go surf!"] = "", -- WxW
--      ["GOTCHA!"] = "",
--      ["Grab Mines/Explosives"] = "",
--      ["Great choice, Steve! Mind if I call you that?"] = "", -- A_Classic_Fairytale:shadow
--      ["Great work! Now hit it with your Baseball Bat! |Tip: You can change weapon with 'Right Click'!"] = "", -- Basic_Training_-_Rope
--      ["Great! You will be contacted soon for assistance."] = "", -- A_Classic_Fairytale:shadow
--      ["Green lipstick bullet: [Is poisonous]"] = "", -- Continental_supplies
--      ["Greetings, "] = "", -- A_Classic_Fairytale:dragon
--      ["Greetings, cloudy one!"] = "", -- A_Classic_Fairytale:shadow
--      ["Grenade Training"] = "", -- Basic_Training_-_Grenade
--      ["Grenadiers"] = "", -- Basic_Training_-_Grenade
--      ["Guys, do you think there's more of them?"] = "", -- A_Classic_Fairytale:backstab
--      ["HAHA!"] = "", -- A_Classic_Fairytale:enemy
--      ["Haha!"] = "", -- A_Classic_Fairytale:united
--      ["Hahahaha!"] = "",
--      ["Haha, now THAT would be something!"] = "",
--      ["Hannibal"] = "", -- A_Classic_Fairytale:epil
--      ["Hapless Hogs"] = "",
--      [" Hapless Hogs left!"] = "",

--      [" HAS MUTATED"] = "", -- Mutant
--      ["Hatless Jerry"] = "", -- A_Classic_Fairytale:queen
--      ["Have no illusions, your tribe is dead, indifferent of your choice."] = "", -- A_Classic_Fairytale:shadow
--      ["Have we ever attacked you first?"] = "", -- A_Classic_Fairytale:enemy
--      ["Health crates extend your time."] = "",
--      ["Heavy"] = "",
--      ["Heavy Cannfantry"] = "", -- A_Classic_Fairytale:united
--      ["Hedge-cogs"] = "", -- A_Classic_Fairytale:enemy
--      ["Hedgehog projectile: [fire your hog like a Sticky Bomb]"] = "", -- Continental_supplies
	["Hedgewars-Basketball"] = "Hedgewars-Basketball",
	["Hedgewars-Knockball"] = "Hedgewars-Knockball",
--      ["Hedgibal Lecter"] = "", -- A_Classic_Fairytale:backstab
--      ["Heh, it's not that bad."] = "",
--      ["Hello again, "] = "", -- A_Classic_Fairytale:family
--      ["Help me, Leaks!"] = "", -- A_Classic_Fairytale:journey
--      ["Help me, please!!!"] = "", -- A_Classic_Fairytale:journey
--      ["Help me, please!"] = "", -- A_Classic_Fairytale:journey
--      ["He moves like an eagle in the sky."] = "", -- A_Classic_Fairytale:first_blood
--      ["He must be in the village already."] = "", -- A_Classic_Fairytale:journey
--      ["Here, let me help you!"] = "", -- A_Classic_Fairytale:backstab
--      ["Here, let me help you save her!"] = "", -- A_Classic_Fairytale:family
--      ["Here...pick your weapon!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Hero Team"] = "", -- User_Mission_-_The_Great_Escape
--      ["He's so brave..."] = "", -- A_Classic_Fairytale:first_blood
--      ["He won't be selling us out anymore!"] = "", -- A_Classic_Fairytale:backstab
--      ["Hey, guys!"] = "", -- A_Classic_Fairytale:backstab
--      ["Hey guys!"] = "", -- A_Classic_Fairytale:united
--      ["Hey! This is cheating!"] = "", -- A_Classic_Fairytale:journey
--      ["HIGHLANDER"] = "", -- Highlander
--      ["Hightime"] = "", -- A_Classic_Fairytale:first_blood
--      ["Hint: Double Jump - Press [Backspace] twice"] = "", -- A_Classic_Fairytale:first_blood
--      ["Hint: Select the BlowTorch, aim and press [Fire]. Press [Fire] again to stop.|Don't blow up the crate."] = "", -- A_Classic_Fairytale:journey
--      ["Hint: Select the LowGravity and press [Fire]."] = "", -- A_Classic_Fairytale:journey
--      ["Hint: you might want to stay out of sight and take all the crates...|"] = "", -- A_Classic_Fairytale:journey
--      ["His arms are so strong!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Hit Combo!"] = "",
--      ["Hmmm..."] = "",
--      ["Hmmm...actually...I didn't either."] = "", -- A_Classic_Fairytale:enemy
--      ["Hmmm, I'll have to find some way of moving him off this anti-portal surface..."] = "", -- portal
--      ["Hmmm...it's a draw. How unfortunate!"] = "", -- A_Classic_Fairytale:enemy
--      ["Hmmm...perhaps a little more time will help."] = "", -- A_Classic_Fairytale:first_blood
--      ["Hogminator"] = "", -- A_Classic_Fairytale:family
--      ["Hogs in sight!"] = "", -- Continental_supplies
--      ["HOLY SHYTE!"] = "", -- Mutant
--      ["Honest Lee"] = "", -- A_Classic_Fairytale:enemy
--      ["Hooray!"] = "",
--      ["Hostage Situation"] = "", -- A_Classic_Fairytale:family
--      ["How can I ever repay you for saving my life?"] = "", -- A_Classic_Fairytale:journey
--      ["How come in a village full of warriors, it's up to me to save it?"] = "", -- A_Classic_Fairytale:dragon
--      ["How difficult would you like it to be?"] = "", -- A_Classic_Fairytale:first_blood
--      ["HOW DO THEY KNOW WHERE WE ARE???"] = "", -- A_Classic_Fairytale:united
--      ["However, if you fail to do so, she dies a most violent death, just like your friend! Muahahaha!"] = "", -- A_Classic_Fairytale:journey
--      ["However, if you fail to do so, she dies a most violent death! Muahahaha!"] = "", -- A_Classic_Fairytale:journey
--      ["However, my mates don't agree with me on letting you go..."] = "", -- A_Classic_Fairytale:dragon
--      [" HP"] = "", -- Mutant
	["Hunter"] = "Artilheiro", --Bazooka, Shotgun, SniperRifle
--      ["I believe there's more of them."] = "", -- A_Classic_Fairytale:backstab
--      ["I can see you have been training diligently."] = "", -- A_Classic_Fairytale:first_blood
--      ["I can't believe it worked!"] = "", -- A_Classic_Fairytale:shadow
--      ["I can't believe this!"] = "", -- A_Classic_Fairytale:enemy
--      ["I can't believe what I'm hearing!"] = "", -- A_Classic_Fairytale:backstab
--      ["I can't wait any more, I have to save myself!"] = "", -- A_Classic_Fairytale:shadow
--      ["I could just teleport myself there..."] = "", -- A_Classic_Fairytale:family
--      ["I'd better get going myself."] = "", -- A_Classic_Fairytale:journey
--      ["I didn't until about a month ago."] = "", -- A_Classic_Fairytale:enemy
--      ["I don't know how you did that.. But good work! |The next one should be easy as cake for you!"] = "", -- Basic_Training_-_Rope
--      ["I feel something...a place! They will arrive near the circles!"] = "", -- A_Classic_Fairytale:backstab
--      ["If only I had a way..."] = "", -- A_Classic_Fairytale:backstab
--      ["If only I were given a chance to explain my being here..."] = "", -- A_Classic_Fairytale:first_blood
--      ["I forgot that she's the daughter of the chief, too..."] = "", -- A_Classic_Fairytale:backstab
--      ["If they try coming here, they can have a taste of my delicious knuckles!"] = "", -- A_Classic_Fairytale:united
--      ["If you agree to provide the information we need, you will be spared!"] = "", -- A_Classic_Fairytale:shadow
--      ["If you can get that crate fast enough, your beloved \"princess\" may go free."] = "", -- A_Classic_Fairytale:journey
--      ["If you decide to help us, though, we will no longer need to find a new governor for the island."] = "", -- A_Classic_Fairytale:shadow
--      ["If you get stuck, use your Desert Eagle or restart the mission!|"] = "", -- A_Classic_Fairytale:journey
--      ["If you know what I mean..."] = "", -- A_Classic_Fairytale:shadow
--      ["If you say so..."] = "", -- A_Classic_Fairytale:shadow

--      ["I guess you'll have to kill them."] = "", -- A_Classic_Fairytale:dragon
--      ["I have come to make you an offering..."] = "", -- A_Classic_Fairytale:shadow
--      ["I have no idea where that mole disappeared...Can you see it?"] = "", -- A_Classic_Fairytale:shadow
--      ["I have to follow that alien."] = "", -- A_Classic_Fairytale:backstab
--      ["I have to get back to the village!"] = "", -- A_Classic_Fairytale:shadow
--      ["I hope you are prepared for a small challenge, young one."] = "", -- A_Classic_Fairytale:first_blood
--      ["I just don't want to sink to your level."] = "", -- A_Classic_Fairytale:backstab
--      ["I just found out that they have captured your princess!"] = "", -- A_Classic_Fairytale:family
--      ["I just wonder where Ramon and Spiky disappeared..."] = "", -- A_Classic_Fairytale:journey
--      ["I'll hold them off while you return to the village!"] = "", -- A_Classic_Fairytale:shadow
--      ["Imagine those targets are the wolves that killed your parents! Take your anger out on them!"] = "", -- A_Classic_Fairytale:first_blood
--      ["I'm...alive? How? Why?"] = "", -- A_Classic_Fairytale:backstab
--      ["I'm a ninja."] = "", -- A_Classic_Fairytale:dragon
--      ["I marked the place of their arrival. You're welcome!"] = "", -- A_Classic_Fairytale:backstab
--      ["I'm certain that this is a misunderstanding, fellow hedgehogs!"] = "", -- A_Classic_Fairytale:first_blood
--      ["I mean, none of you ceased to live."] = "", -- A_Classic_Fairytale:enemy
--      ["I'm getting old for this!"] = "", -- A_Classic_Fairytale:family
--      ["I'm getting thirsty..."] = "", -- A_Classic_Fairytale:family
--      ["I'm here to help you rescue her."] = "", -- A_Classic_Fairytale:family
--      ["I'm not sure about that!"] = "", -- A_Classic_Fairytale:united
--      ["Impressive...you are still dry as the corpse of a hawk after a week in the desert..."] = "", -- A_Classic_Fairytale:first_blood
--      ["I'm so scared!"] = "", -- A_Classic_Fairytale:united
--      ["Incredible..."] = "", -- A_Classic_Fairytale:shadow
--      ["I need to find the others!"] = "", -- A_Classic_Fairytale:backstab
--      ["I need to get to the other side of this island, fast!"] = "", -- A_Classic_Fairytale:journey
--      ["I need to move the tribe!"] = "", -- A_Classic_Fairytale:united
--      ["I need to prevent their arrival!"] = "", -- A_Classic_Fairytale:backstab
--      ["I need to warn the others."] = "", -- A_Classic_Fairytale:backstab
--      ["In fact, you are the only one that's been acting strangely."] = "", -- A_Classic_Fairytale:backstab
--      ["In order to get to the other side, you need to collect the crates first.|"] = "", -- A_Classic_Fairytale:dragon
--      ["Instructor"] = "", -- 01#Boot_Camp, User_Mission_-_Dangerous_Ducklings
--      ["Interesting idea, haha!"] = "", -- A_Classic_Fairytale:enemy
--      ["Interesting! Last time you said you killed a cannibal!"] = "", -- A_Classic_Fairytale:backstab
--      ["In the meantime, take these and return to your \"friend\"!"] = "", -- A_Classic_Fairytale:shadow
--      ["invaders destroyed"] = "",
--      ["Invasion"] = "", -- A_Classic_Fairytale:united
--      ["I saw it with my own eyes!"] = "", -- A_Classic_Fairytale:shadow
--      ["I see..."] = "", -- A_Classic_Fairytale:shadow
--      ["I see you have already taken the leap of faith."] = "", -- A_Classic_Fairytale:first_blood
--      ["I see you would like his punishment to be more...personal..."] = "", -- A_Classic_Fairytale:first_blood
--      ["I sense another wave of cannibals heading my way!"] = "", -- A_Classic_Fairytale:backstab
--      ["I sense another wave of cannibals heading our way!"] = "", -- A_Classic_Fairytale:backstab
--      ["I shouldn't have drunk that last pint."] = "", -- A_Classic_Fairytale:dragon
--      ["Is this place in my head?"] = "", -- A_Classic_Fairytale:dragon
--      ["It doesn't matter. I won't let that alien hurt my daughter!"] = "", -- A_Classic_Fairytale:dragon
--      ["I think we are safe here."] = "", -- A_Classic_Fairytale:backstab
--      ["I thought their shaman died when he tried our medicine!"] = "", -- A_Classic_Fairytale:shadow
--      ["It is called 'Hogs of Steel'."] = "", -- A_Classic_Fairytale:enemy
--      ["It is time to practice your fighting skills."] = "", -- A_Classic_Fairytale:first_blood
--      ["It must be a childhood trauma..."] = "", -- A_Classic_Fairytale:family
--      ["It must be the aliens!"] = "", -- A_Classic_Fairytale:backstab
--      ["It must be the aliens' deed."] = "", -- A_Classic_Fairytale:backstab
--      ["It must be the cyborgs again!"] = "", -- A_Classic_Fairytale:enemy
--      ["I told you, I just found them."] = "", -- A_Classic_Fairytale:backstab
--      ["It's a good thing SUDDEN DEATH is 99 turns away..."] = "",
--      ["It's always up to women to clear up the mess men created!"] = "", -- A_Classic_Fairytale:dragon
--      ["It's a shame, I forgot how to do that!"] = "", -- A_Classic_Fairytale:family
--      ["It's impossible to communicate with the spirits without a shaman."] = "", -- A_Classic_Fairytale:shadow
--      ["It's over..."] = "", -- A_Classic_Fairytale:shadow
--      ["It's time you learned that your actions have consequences!"] = "", -- A_Classic_Fairytale:journey
--      ["It's worth more than wood!"] = "", -- A_Classic_Fairytale:enemy
--      ["It wants our brains!"] = "", -- A_Classic_Fairytale:shadow
--      ["It was not a dream, unwise one!"] = "", -- A_Classic_Fairytale:backstab
--      ["I've seen this before. They just appear out of thin air."] = "", -- A_Classic_Fairytale:united
--      ["I want to play a game..."] = "", -- A_Classic_Fairytale:journey
--      ["I want to see how it handles this!"] = "", -- A_Classic_Fairytale:backstab
--      ["I wish to help you, "] = "", -- A_Classic_Fairytale:dragon
--      ["I wonder where Dense Cloud is..."] = "", -- A_Classic_Fairytale:journey, A_Classic_Fairytale:shadow
--      ["I wonder why I'm so angry all the time..."] = "", -- A_Classic_Fairytale:family
--      ["I won't let you kill her!"] = "", -- A_Classic_Fairytale:journey
--      ["Jack"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
--      ["Jeremiah"] = "", -- A_Classic_Fairytale:dragon
--      ["John"] = "", -- A_Classic_Fairytale:journey
--      ["Judas"] = "", -- A_Classic_Fairytale:backstab
--      ["Jumping is disabled"] = "",
--      ["Just kidding, none of you have died!"] = "", -- A_Classic_Fairytale:enemy
--      ["Just on a walk."] = "", -- A_Classic_Fairytale:united
--      ["Just wait till I get my hands on that trauma! ARGH!"] = "", -- A_Classic_Fairytale:family
--      ["Kamikaze Expert!"] = "",
--      ["Keep it up!"] = "",
--      ["Kerguelen"] = "", -- Continental_supplies
--      ["Killing spree!"] = "",
--      ["KILL IT!"] = "", -- A_Classic_Fairytale:first_blood
--      ["KILLS"] = "",
--      ["Kill the aliens!"] = "", -- A_Classic_Fairytale:dragon
--      ["Kill the cannibal!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Kill the traitor...or spare his life!|Kill him or press [Precise]!"] = "", -- A_Classic_Fairytale:backstab
--      ["Last Target!"] = "",
--      ["Leader"] = "", -- A_Classic_Fairytale:enemy
--      ["Leaderbot"] = "", -- A_Classic_Fairytale:queen
--      ["Leaks A Lot"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:first_blood, A_Classic_Fairytale:journey, A_Classic_Fairytale:queen, A_Classic_Fairytale:shadow, A_Classic_Fairytale:united
--      ["Leaks A Lot, depressed for killing his loved one, failed to save the village..."] = "", -- A_Classic_Fairytale:journey
--      ["Leaks A Lot gave his life for his tribe! He should have survived!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Leaks A Lot must survive!"] = "", -- A_Classic_Fairytale:journey
--      ["Led Heart"] = "", -- A_Classic_Fairytale:queen
--      ["Lee"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
--      ["[Left Shift]"] = "",
--      ["Let a Continent provide your weapons!"] = "", -- Continental_supplies
--      ["Let me test your skills a little, will you?"] = "", -- A_Classic_Fairytale:journey
--      ["Let's go home!"] = "", -- A_Classic_Fairytale:journey
--      ["Let's head back to the village!"] = "", -- A_Classic_Fairytale:shadow
--      ["Let's see what your comrade does now!"] = "", -- A_Classic_Fairytale:journey
--      ["Let's show those cannibals what we're made of!"] = "", -- A_Classic_Fairytale:backstab
--      ["Let them have a taste of my fury!"] = "", -- A_Classic_Fairytale:backstab
--      ["Let us help, too!"] = "", -- A_Classic_Fairytale:backstab
--      ["Light Cannfantry"] = "", -- A_Classic_Fairytale:united
--      ["Listen up, maggot!!"] = "",
--      ["Little did they know that this hunt will mark them forever..."] = "", -- A_Classic_Fairytale:shadow
--      ["Lively Lifeguard"] = "",
--      ["Lonely Cries: [Rise the water if no hog is in the circle and deal 1 damage to all hogs]"] = "", -- Continental_supplies
--      ["Look, I had no choice!"] = "", -- A_Classic_Fairytale:backstab
--      ["Look out! There's more of them!"] = "", -- A_Classic_Fairytale:backstab
--      ["Look out! We're surrounded by cannibals!"] = "", -- A_Classic_Fairytale:enemy
--      ["Looks like the whole world is falling apart!"] = "", -- A_Classic_Fairytale:enemy
--      ["Luckily, I've managed to snatch some of them."] = "", -- A_Classic_Fairytale:united
--      ["LUDICROUS KILL"] = "", -- Mutant
--      ["May the spirits aid you in all your quests!"] = "", -- A_Classic_Fairytale:backstab
--      ["Medicine: [Fire some exploding medicine that will heal all hogs effected by the explosion]"] = "", -- Continental_supplies
--      ["MEGA KILL"] = "", -- Mutant
--      ["Meiwes"] = "", -- A_Classic_Fairytale:backstab
--      ["Mindy"] = "", -- A_Classic_Fairytale:united
--      ["Mine Deployer"] = "",
--      ["Mine Eater!"] = "",
--      ["|- Mines Time:"] = "", -- User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
--      ["MISSION FAILED"] = "", -- User_Mission_-_Dangerous_Ducklings, User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
--      ["MISSION SUCCESS"] = "",
--      ["MISSION SUCCESSFUL"] = "", -- User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
--      ["Molotov"] = "", -- Continental_supplies
--      ["MONSTER KILL"] = "", -- Mutant
--      ["More Natives"] = "", -- A_Classic_Fairytale:epil
--      ["Movement: [Up], [Down], [Left], [Right]"] = "",
--      ["Multi-shot!"] = "",
--      ["Muriel"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
--      ["Muscle Dissolver"] = "", -- A_Classic_Fairytale:shadow
--      ["-------"] = "", -- Mutant
--      ["Nade Boy"] = "", -- Basic_Training_-_Grenade
--      ["Name"] = "", -- A_Classic_Fairytale:queen
--      ["Nameless Heroes"] = "",
--      ["Nancy Screw"] = "", -- A_Classic_Fairytale:enemy, A_Classic_Fairytale:queen
--      ["Napalm rocket: [Fire a bomb with napalm!]"] = "", -- Continental_supplies
--      ["Natives"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:first_blood, A_Classic_Fairytale:journey, A_Classic_Fairytale:queen, A_Classic_Fairytale:shadow, A_Classic_Fairytale:united
--      ["New Barrels Per Turn"] = "",
--      ["NEW CLAN RECORD: "] = "",
	["NEW fastest lap: "] = "NOVA volta mais rápida: ",
--      ["New Mines Per Turn"] = "",
--      ["NEW RACE RECORD: "] = "",
--      ["Newton's Hammock"] = "",
--      ["Nicely done, meatbags!"] = "", -- A_Classic_Fairytale:enemy
--      ["Nice work, "] = "", -- A_Classic_Fairytale:dragon
--      ["Nice work!"] = "", -- A_Classic_Fairytale:enemy
--      ["Nilarian"] = "", -- A_Classic_Fairytale:queen
--      ["No, I came back to help you out..."] = "", -- A_Classic_Fairytale:shadow
--      ["No...I wonder where they disappeared?!"] = "", -- A_Classic_Fairytale:journey
--      ["Nom-Nom"] = "", -- A_Classic_Fairytale:journey
--      ["NomNom"] = "", -- A_Classic_Fairytale:united
--      ["Nope. It was one fast mole, that's for sure."] = "", -- A_Classic_Fairytale:shadow
--      ["No! Please, help me!"] = "", -- A_Classic_Fairytale:journey
--      ["NORMAL"] = "", -- Continental_supplies
--      ["North America"] = "", -- Continental_supplies
--      ["Not all hogs are born equal."] = "", -- Highlander
--      ["NOT ENOUGH WAYPOINTS"] = "",
--      ["Not now, Fiery Water!"] = "", -- A_Classic_Fairytale:backstab
	["Not So Friendly Match"] = "Partida não muito amigável", -- Basketball, Knockball
--      ["Not you again! My head still hurts from last time!"] = "", -- A_Classic_Fairytale:shadow
--      ["No, we made sure of that!"] = "", -- A_Classic_Fairytale:united
--      ["Now find the next target! |Tip: Normally you lose health by falling down, so be careful!"] = "", -- Basic_Training_-_Rope
--      ["No! What have I done?! What have YOU done?!"] = "", -- A_Classic_Fairytale:journey
--      ["No. Where did he come from?"] = "", -- A_Classic_Fairytale:shadow
--      ["Now how do I get on the other side?!"] = "", -- A_Classic_Fairytale:dragon
--      ["No. You and the rest of the tribe are safer there!"] = "", -- A_Classic_Fairytale:backstab
--      ["Obliterate them!|Hint: You might want to take cover..."] = "", -- A_Classic_Fairytale:shadow
--      ["Obstacle course"] = "", -- A_Classic_Fairytale:dragon
--      ["Of course I have to save her. What did I expect?!"] = "", -- A_Classic_Fairytale:family
--      ["OH, COME ON!"] = "", -- A_Classic_Fairytale:journey
--      ["Oh, my!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Oh, my! This is even more entertaining than I've expected!"] = "", -- A_Classic_Fairytale:backstab
--      ["Oh no! Just try again!"] = "", -- User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
--      ["Oh no, not "] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:united
	["Oh no! Time's up! Just try again."] = "Oh não! O tempo acabou! Tente novamente.", --Bazooka, Shotgun, SniperRifle
--      ["Oh no! You failed! Just try again."] = "", -- Basic_Training_-_Cluster_Bomb
--      ["Oh, silly me! I forgot that I'm the shaman."] = "", -- A_Classic_Fairytale:backstab
--      ["Olive"] = "", -- A_Classic_Fairytale:united
--      ["Omnivore"] = "", -- A_Classic_Fairytale:first_blood
      ["Once upon a time, on an island with great natural resources, lived two tribes in heated conflict..."] = "Era uma vez, em uma ilha com ótimos recursos naturais, duas tribos que viviam em intenso conflito...", -- A_Classic_Fairytale:first_blood
--      ["ONE HOG PER TEAM! KILLING EXCESS HEDGES"] = "", -- Mutant
--      ["One tribe was peaceful, spending their time hunting and training, enjoying the small pleasures of life..."] = "", -- A_Classic_Fairytale:first_blood
--      ["Oops...I dropped them."] = "", -- A_Classic_Fairytale:united
--      ["Open that crate and we will continue!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Operation Diver"] = "",
--      ["Opposing Team: "] = "",
--      ["Orlando Boom!"] = "", -- A_Classic_Fairytale:queen
--      ["Ouch!"] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["Our tribe, our beautiful island!"] = "", -- A_Classic_Fairytale:enemy
--      ["Parachute"] = "", -- Continental_supplies
--      ["Pathetic Hog #%d"] = "",
--      ["Pathetic Resistance"] = "", -- User_Mission_-_Bamboo_Thicket, User_Mission_-_Newton_and_the_Hammock
--      ["Perfect! Now try to get the next crate without hurting yourself!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Per-Hog Ammo"] = "",
--      ["- Per team weapons|- 9 weaponschemes|- Unique new weapons| |Select continent first round with the Weapon Menu or by ([switch/tab]=Increase,[precise/left shift]=Decrease) on Skip|Some weapons have a second option. Find them with [switch/tab]"] = "", -- Continental_supplies

--      ["Pfew! That was close!"] = "", -- A_Classic_Fairytale:shadow
--      ["Piñata bullet: [Contains some sweet candy!]"] = "", -- Continental_supplies
--      ["Pings left:"] = "", -- Space_Invasion

--      ["Place more waypoints using the 'Air Attack' weapon."] = "",
--      ["Planes Used:"] = "", -- User_Mission_-_RCPlane_Challenge
--      ["Planes Used"] = "", -- User_Mission_-_RCPlane_Challenge
--      ["Play with me!"] = "", -- A_Classic_Fairytale:shadow
--      ["Please place the way-point further from the waterline."] = "", -- Racer
--      ["Please place the way-point in the open, within the map boundaries."] = "", -- Racer
--      ["Please, stop releasing your \"smoke signals\"!"] = "", -- A_Classic_Fairytale:shadow
--      ["Point Blank Combo!"] = "", -- Space_Invasion
--      ["points"] = "", -- Control, CTF_Blizzard, Basic_Training_-_Bazooka, Basic_Training_-_Shotgun, Basic_Training_-_Sniper_Rifle
--      ["Poison"] = "",
--      ["Portal hint: one goes to the destination, and one is the entrance.|"] = "", -- A_Classic_Fairytale:dragon
--      ["Portal mission"] = "", -- portal
--      ["Power Remaining"] = "",
--      ["Prepare yourself"] = "",
--      ["Press [Enter] to accept this configuration."] = "", -- WxW
--      ["Press [Left] or [Right] to move around, [Enter] to jump"] = "", -- A_Classic_Fairytale:first_blood
--      ["Press [Precise] to skip intro"] = "",
--      ["Private Novak"] = "", -- Basic_Training_-_Cluster_Bomb
--      ["Protect yourselves!|Grenade hint: set the timer with [1-5], aim with [Up]/[Down] and hold [Space] to set power"] = "", -- A_Classic_Fairytale:shadow
--      ["Race complexity limit reached."] = "",
--      ["RACER"] = "",
--      ["Rachel"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
--      ["Radar Ping"] = "", -- Space_Invasion
--      ["Raging Buffalo"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:queen, A_Classic_Fairytale:united
--      ["Ramon"] = "", -- A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:queen, A_Classic_Fairytale:shadow
--      ["RC PLANE TRAINING"] = "", -- User_Mission_-_RCPlane_Challenge
--      ["Really?! You thought you could harm me with your little toys?"] = "", -- A_Classic_Fairytale:shadow
--      ["Regurgitator"] = "", -- A_Classic_Fairytale:backstab
--      ["Reinforcements"] = "", -- A_Classic_Fairytale:backstab
--      ["Remember: The rope only bend around objects, |if it doesn't hit anything it's always stright!"] = "", -- Basic_Training_-_Rope
--      ["Remember this, pathetic animal: when the day comes, you will regret your blind loyalty!"] = "", -- A_Classic_Fairytale:shadow
--      [" - Return the enemy flag to your base to score | - First team to 3 captures wins | - You may only score when your flag is in your base | - Hogs will drop the flag if killed, or drowned | - Dropped flags may be returned or recaptured | - Hogs respawn when killed"] = "",
--      ["Return to Leaks A Lot! If you get stuck, press [Precise] to try again!"] = "", -- A_Classic_Fairytale:shadow
--      ["Righteous Beard"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:first_blood, A_Classic_Fairytale:queen, A_Classic_Fairytale:united
--      ["ROPE-KNOCKING"] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["Rope Training"] = "", -- Basic_Training_-_Rope
--      ["Rot Molester"] = "", -- A_Classic_Fairytale:shadow
--      ["Round Limit:"] = "",
--      ["Round Limit"] = "",
--      ["Rounds Complete: "] = "",
--      ["Rounds Complete"] = "",
--      ["RULES OF THE GAME [Press ESC to view]"] = "",
--      ["Rusty Joe"] = "", -- A_Classic_Fairytale:queen
--      ["s|"] = "",
--      ["Sabotage: [Sabotage all hogs in the circle and deal ~10 dmg]"] = "", -- Continental_supplies
--      ["Salivaslurper"] = "", -- A_Classic_Fairytale:united
--      ["Salvation"] = "", -- A_Classic_Fairytale:family
--      ["Salvation was one step closer now..."] = "", -- A_Classic_Fairytale:dragon
--      ["Save as many hapless hogs as possible!"] = "",
--      ["Save Fell From Heaven!"] = "", -- A_Classic_Fairytale:journey
--      ["Save Leaks A Lot!|Hint: The Switch utility might be of help to you."] = "", -- A_Classic_Fairytale:shadow
--      ["Save the princess! All your hogs must survive!|Hint: Kill the cyborgs first! Use the ammo very carefully!|Hint: You might want to spare a girder for cover!"] = "", -- A_Classic_Fairytale:family
--      ["Save the princess by collecting the crate in under 12 turns!"] = "", -- A_Classic_Fairytale:journey
--      ["Scalp Muncher"] = "", -- A_Classic_Fairytale:backstab
--      ["SCORE"] = "",
--      ["Score"] = "", -- Mutant
--      ["Scream from a Walrus: [Deal 20 damage + 10% of your hogs health to all hogs around you and get half back]"] = "", -- Continental_supplies
--      ["sec"] = "", -- CTF_Blizzard, TrophyRace, Basic_Training_-_Bazooka, Basic_Training_-_Shotgun, Basic_Training_-_Sniper_Rifle, User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork, Capture_the_Flag
--      ["Seduction"] = "", -- Continental_supplies
--      ["Seems like every time you take a \"walk\", the enemy find us!"] = "", -- A_Classic_Fairytale:backstab
--      ["See that crate farther on the right?"] = "", -- A_Classic_Fairytale:first_blood
--      ["See ya!"] = "",
--      ["Segmentation Paul"] = "", -- A_Classic_Fairytale:dragon
--      ["Select continent!"] = "", -- Continental_supplies
--      ["Select difficulty: [Left] - easier or [Right] - harder"] = "", -- A_Classic_Fairytale:first_blood
--      ["selected!"] = "",
--      ["s"] = "", -- GaudyRacer, Space_Invasion
--      ["... share your beauty with the world every morning, my princess!"] = "", -- A_Classic_Fairytale:journey
--      ["She's behind that tall thingy."] = "", -- A_Classic_Fairytale:family
--      ["Shield boosted! +30 power"] = "",
--      ["Shield Depleted"] = "",
--      ["Shield is fully recharged!"] = "",
--      ["Shield Master!"] = "",
--      ["Shield Miser!"] = "",
--      ["Shield OFF:"] = "",
--      ["Shield ON:"] = "",
--      ["Shield Seeker!"] = "",
--      ["Shotgun"] = "", -- Continental_supplies
	["Shotgun Team"] = "Carabineiros",
	["Shotgun Training"] = "Treino com a Escopeta",
--      ["shots remaining."] = "",
--      ["Silly"] = "",
--      ["Sinky"] = "",
--      ["Sirius Lee"] = "", -- A_Classic_Fairytale:enemy
	["%s is out and Team %d|scored a penalty!| |Score:"] = "%s está fora e a Equipe %d|sofreu uma penalidade!| |Pontuação:", -- Basketball, Knockball
	["%s is out and Team %d|scored a point!| |Score:"] = "%s está fora e a Equipe %d|marcou um ponto!| |Pontuação:", -- Basketball, Knockball
--      ["Slippery"] = "", -- A_Classic_Fairytale:journey
--      ["Smith 0.97"] = "", -- A_Classic_Fairytale:enemy
--      ["Smith 0.98"] = "", -- A_Classic_Fairytale:enemy
--      ["Smith 0.99a"] = "", -- A_Classic_Fairytale:enemy
--      ["Smith 0.99b"] = "", -- A_Classic_Fairytale:enemy
--      ["Smith 0.99f"] = "", -- A_Classic_Fairytale:enemy
--      ["Smith 1.0"] = "", -- A_Classic_Fairytale:enemy
--      ["Sniper Rifle"] = "", -- Continental_supplies
--      ["Sniper!"] = "", -- Space_Invasion
	["Sniper Training"] = "Treino com o Rifle Sniper",
	["Sniperz"] = "Franco-Atiradores",
--      ["So humiliating..."] = "", -- A_Classic_Fairytale:first_blood
--      ["South America"] = "", -- Continental_supplies
--      ["So? What will it be?"] = "", -- A_Classic_Fairytale:shadow
--      ["Spawn the crate, and attack!"] = "", -- WxW
--      ["Special Weapons:"] = "", -- Continental_supplies
--      ["Spiky Cheese"] = "", -- A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:queen, A_Classic_Fairytale:shadow
--      ["Spleenlover"] = "", -- A_Classic_Fairytale:united
--      ["Sponge"] = "",
--      ["Spooky Tree"] = "",
--      ["STATUS UPDATE"] = "", -- GaudyRacer, Space_Invasion
--      ["Steel Eye"] = "", -- A_Classic_Fairytale:queen
--      ["Step By Step"] = "", -- A_Classic_Fairytale:first_blood
--      ["Steve"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
--      ["Sticky Mine"] = "", -- Continental_supplies
--      ["Stronglings"] = "", -- A_Classic_Fairytale:shadow
--      ["Structure"] = "", -- Continental_supplies
--      ["Super Weapons"] = "", -- WxW
--      ["Surf Before Crate"] = "", -- WxW
--      ["Surfer! +15 points!"] = "", -- Space_Invasion
--      ["Surfer!"] = "", -- WxW
--      ["Survive!|Hint: Cinematics can be skipped with the [Precise] key."] = "", -- A_Classic_Fairytale:shadow
--      ["Swing, Leaks A Lot, on the wings of the wind!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Switched to "] = "",
--      ["Syntax Errol"] = "", -- A_Classic_Fairytale:dragon
--      ["Talk about mixed signals..."] = "", -- A_Classic_Fairytale:dragon
	["Team %d: "] = "Equipe %d: ",
--      ["Team Scores"] = "", -- Control, Space_Invasion
--      ["Teleport hint: just use the mouse to select the destination!"] = "", -- A_Classic_Fairytale:dragon
--      ["Thanks!"] = "", -- A_Classic_Fairytale:family
--      ["Thank you, my hero!"] = "", -- A_Classic_Fairytale:family
--      ["Thank you, oh, thank you, Leaks A Lot!"] = "", -- A_Classic_Fairytale:journey
--      ["Thank you, oh, thank you, my heroes!"] = "", -- A_Classic_Fairytale:journey
--      ["That is, indeed, very weird..."] = "", -- A_Classic_Fairytale:united
--      ["That makes it almost invaluable!"] = "", -- A_Classic_Fairytale:enemy
--      ["That ought to show them!"] = "", -- A_Classic_Fairytale:backstab
--      ["That's for my father!"] = "", -- A_Classic_Fairytale:backstab
--      ["That shaman sure knows what he's doing!"] = "", -- A_Classic_Fairytale:shadow
--      ["That Sinking Feeling"] = "",
--      ["That's not our problem!"] = "", -- A_Classic_Fairytale:enemy
--      ["That's typical of you!"] = "", -- A_Classic_Fairytale:family
--      ["That was just mean!"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:united
--      ["That was pointless."] = "",
--      ["The answer is...entertaintment. You'll see what I mean."] = "", -- A_Classic_Fairytale:backstab
--      ["The anti-portal zone is all over the floor, and I have nothing to kill him...Droping something could hurt him enough to kill him..."] = "", -- portal
--      ["The Bull's Eye"] = "", -- A_Classic_Fairytale:first_blood
--      ["The caves are well hidden, they won't find us there!"] = "", -- A_Classic_Fairytale:united
--      ["The Crate Frenzy"] = "", -- A_Classic_Fairytale:first_blood
--      ["The Dilemma"] = "", -- A_Classic_Fairytale:shadow
--      ["The enemy can't move but it might be a good idea to stay out of sight!|"] = "", -- A_Classic_Fairytale:dragon
--      ["The enemy is hiding out on yonder ducky!"] = "",
--      ["The Enemy Of My Enemy"] = "", -- A_Classic_Fairytale:enemy
--      ["The First Blood"] = "", -- A_Classic_Fairytale:first_blood
--      ["The First Encounter"] = "", -- A_Classic_Fairytale:shadow
--      ["The flag will respawn next round."] = "",
--      ["The food bites back"] = "", -- A_Classic_Fairytale:backstab
--      ["The giant umbrella from the last crate should help break the fall."] = "", -- A_Classic_Fairytale:first_blood
--      ["The Great Escape"] = "", -- User_Mission_-_The_Great_Escape
--      ["The guardian"] = "", -- A_Classic_Fairytale:shadow
--      ["The Individualist"] = "", -- A_Classic_Fairytale:shadow
--      ["Their buildings were very primitive back then, even for an uncivilised island."] = "", -- A_Classic_Fairytale:united
--      ["The Journey Back"] = "", -- A_Classic_Fairytale:journey
--      ["The Leap of Faith"] = "", -- A_Classic_Fairytale:first_blood
--      ["The Moonwalk"] = "", -- A_Classic_Fairytale:journey
--      ["The Nameless One"] = "",
--      ["The next one is pretty hard! |Tip: You have to do multiple swings!"] = "", -- Basic_Training_-_Rope
--      ["Then how do they keep appearing?"] = "", -- A_Classic_Fairytale:shadow
--      ["The other one were all cannibals, spending their time eating the organs of fellow hedgehogs..."] = "", -- A_Classic_Fairytale:first_blood
--      ["There must be a spy among us!"] = "", -- A_Classic_Fairytale:backstab
--      ["There's more of them? When did they become so hungry?"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:united
--      ["There's nothing more satisfying for me than seeing you share your beauty with the world every morning, my princess!"] = "", -- A_Classic_Fairytale:journey
--      ["There's nothing more satisfying to us than seeing you share your beauty..."] = "", -- A_Classic_Fairytale:journey
--      ["There's nothing more satisfying to us than seeing you share your beauty with the world every morning, my princess!"] = "", -- A_Classic_Fairytale:journey
--      ["The Rising"] = "", -- A_Classic_Fairytale:first_blood
--      ["The Savior"] = "", -- A_Classic_Fairytale:journey
--      ["These primitive people are so funny!"] = "", -- A_Classic_Fairytale:backstab
--      ["The Shadow Falls"] = "", -- A_Classic_Fairytale:shadow
--      ["The Showdown"] = "", -- A_Classic_Fairytale:shadow
--      ["The Slaughter"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:first_blood
--      ["THE SPECIALISTS"] = "",
--      ["The spirits of the ancerstors are surely pleased, Leaks A Lot."] = "", -- A_Classic_Fairytale:first_blood
--      ["The Torment"] = "", -- A_Classic_Fairytale:first_blood
--      ["The Tunnel Maker"] = "", -- A_Classic_Fairytale:journey
--      ["The Ultimate Weapon"] = "", -- A_Classic_Fairytale:first_blood
--      ["The Union"] = "", -- A_Classic_Fairytale:enemy
--      ["The village, unprepared, was destroyed by the cyborgs..."] = "", -- A_Classic_Fairytale:journey
--      ["The walk of Fame"] = "", -- A_Classic_Fairytale:shadow
--      ["The wasted youth"] = "", -- A_Classic_Fairytale:first_blood
--      ["The weapon in that last crate was bestowed upon us by the ancients!"] = "", -- A_Classic_Fairytale:first_blood
--      ["The what?!"] = "", -- A_Classic_Fairytale:dragon
--      ["The wind whispers that you are ready to become familiar with tools, now..."] = "", -- A_Classic_Fairytale:first_blood
--      ["They are all waiting back in the village, haha."] = "", -- A_Classic_Fairytale:enemy
--      ["They Call Me Bullseye!"] = "", -- Space_Invasion
--      ["They have weapons we've never seen before!"] = "", -- A_Classic_Fairytale:united
--      ["They keep appearing like this. It's weird!"] = "", -- A_Classic_Fairytale:united
--      ["They killed "] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:united
--      ["They must be trying to weaken us!"] = "", -- A_Classic_Fairytale:enemy
--      ["They never learn"] = "", -- A_Classic_Fairytale:journey
--      ["They told us to wear these clothes. They said that this is the newest trend."] = "", -- A_Classic_Fairytale:enemy
--      ["They've been manipulating us all this time!"] = "", -- A_Classic_Fairytale:enemy
--      ["Thighlicker"] = "", -- A_Classic_Fairytale:united
--      ["This is it! It's time to make Fell From Heaven fall for me..."] = "", -- A_Classic_Fairytale:first_blood
--      ["This island is the only place left on Earth with grass on it!"] = "", -- A_Classic_Fairytale:enemy
--      ["This is typical!"] = "", -- A_Classic_Fairytale:dragon
--      ["This must be some kind of sorcery!"] = "", -- A_Classic_Fairytale:shadow
--      ["This must be the caves!"] = "", -- A_Classic_Fairytale:backstab
--      ["This one's tricky."] = "",
--      ["This rain is really something..."] = "",
--      ["This will be fun!"] = "", -- A_Classic_Fairytale:enemy
--      ["Those aliens are destroying the island!"] = "", -- A_Classic_Fairytale:family
--      ["TIME: "] = "",
--      ["Timed Kamikaze!"] = "",
--      ["Time Extended!"] = "",
--      ["Time Extension"] = "",
--      ["Tip: The rope physics are different than in the real world, |use it to your advantage!"] = "", -- Basic_Training_-_Rope
--      ["Toggle Shield"] = "",
--      ["To help you, of course!"] = "", -- A_Classic_Fairytale:journey
--      ["To place a girder, select it, use [Left] and [Right] to select angle and length, place with [Left Click]"] = "", -- A_Classic_Fairytale:shadow
--      ["Torn Muscle"] = "", -- A_Classic_Fairytale:journey
--      [" to save the village."] = "", -- A_Classic_Fairytale:dragon
--      ["To the caves..."] = "", -- A_Classic_Fairytale:united
--      ["Toxic Team"] = "", -- User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
--      ["TRACK COMPLETED"] = "",
--      ["TRACK FAILED!"] = "",
--      ["training"] = "", -- portal
--      ["Traitors"] = "", -- A_Classic_Fairytale:epil
--      ["Tribe"] = "", -- A_Classic_Fairytale:backstab
	["TrophyRace"] = "TrophyRace",
--      ["Try to protect the chief! You won't lose if he dies, but it is advised that he survives."] = "", -- A_Classic_Fairytale:united
--      ["T_T"] = "",
--      ["Tumbling Time Extended!"] = "",
--      ["Turns until Sudden Death: "] = "", -- A_Classic_Fairytale:dragon
--      [" turns until Sudden Death! Better hurry!"] = "", -- A_Classic_Fairytale:dragon
--      ["Turn Time"] = "",
--      ["Two little hogs cooperating, getting past obstacles..."] = "", -- A_Classic_Fairytale:journey
--      ["Uhm...I met one of them and took his weapons."] = "", -- A_Classic_Fairytale:shadow
--      ["Uhmm...ok no."] = "", -- A_Classic_Fairytale:enemy
--      ["ULTRA KILL"] = "", -- Mutant
--      ["Under Construction"] = "", -- A_Classic_Fairytale:shadow
--      ["Unexpected Igor"] = "", -- A_Classic_Fairytale:dragon
--      ["Unit"] = "",
--      ["Unit 0x0007"] = "", -- A_Classic_Fairytale:family
--      ["Unit 334a$7%;.*"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:family, A_Classic_Fairytale:queen, A_Classic_Fairytale:united
--      ["Unit 3378"] = "",
--      ["Unit 835"] = "",
--      ["United We Stand"] = "", -- A_Classic_Fairytale:united
--      ["Unlimited Attacks"] = "",
--      ["Unlucky Sods"] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["Unstoppable!"] = "",
--      ["Unsuspecting Louts"] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["[Up], [Down] to aim, [Space] to shoot!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Use it wisely!"] = "", -- A_Classic_Fairytale:dragon
--      ["Use it with precaution!"] = "", -- A_Classic_Fairytale:first_blood
--      ["User Challenge"] = "",

--      ["Use the portal gun to get to the next crate, then use the new gun to get to the final destination!|"] = "", -- A_Classic_Fairytale:dragon
--      ["Use the rope to get on the head of the mole, young one!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Use the rope to knock your enemies to their doom."] = "", -- User_Mission_-_Rope_Knock_Challenge
	["Use your rope to get from start to finish as fast as you can!"] = "Use sua corda para ir do início ao fim o mais rápido que você puder!",
--      ["Vedgies"] = "", -- A_Classic_Fairytale:journey
--      ["Vegan Jack"] = "", -- A_Classic_Fairytale:enemy
--      ["Victory!"] = "", -- Basic_Training_-_Rope
--      ["Victory for the "] = "", -- CTF_Blizzard, Capture_the_Flag
--      ["Violence is not the answer to your problems!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Walls Left"] = "", -- WxW
--      ["Walls Required"] = "", -- WxW
--      ["WALL TO WALL"] = "", -- WxW
--      ["Wannabe Flyboys"] = "", -- User_Mission_-_RCPlane_Challenge
--      ["Wannabe Shoppsta"] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["Watch your steps, young one!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Waypoint placed."] = "",
--      ["Way-Points Remaining"] = "",
--      ["Weaklings"] = "", -- A_Classic_Fairytale:shadow
--      ["We all know what happens when you get frightened..."] = "", -- A_Classic_Fairytale:first_blood
--      ["Weapons Reset"] = "",
--      ["Weapons reset."] = "", -- Highlander
--      ["We are indeed."] = "", -- A_Classic_Fairytale:backstab
--      ["We can't defeat them!"] = "", -- A_Classic_Fairytale:shadow
--      ["We can't hold them up much longer!"] = "", -- A_Classic_Fairytale:united
--      ["We can't let them take over our little island!"] = "", -- A_Classic_Fairytale:enemy
--      ["We have no time to waste..."] = "", -- A_Classic_Fairytale:journey
--      ["We have nowhere else to live!"] = "", -- A_Classic_Fairytale:enemy
--      ["We have to protect the village!"] = "", -- A_Classic_Fairytale:united
--      ["We have to unite and defeat those cylergs!"] = "", -- A_Classic_Fairytale:enemy
--      ["Welcome, Leaks A Lot!"] = "", -- A_Classic_Fairytale:journey
--      ["Well done."] = "",
--      ["We'll give you a problem then!"] = "", -- A_Classic_Fairytale:enemy
--      ["We'll spare your life for now!"] = "", -- A_Classic_Fairytale:backstab
--      ["Well, that was a waste of time."] = "", -- A_Classic_Fairytale:dragon
--      ["Well, well! Isn't that the cutest thing you've ever seen?"] = "", -- A_Classic_Fairytale:journey
--      ["Well, yes. This was a cyborg television show."] = "", -- A_Classic_Fairytale:enemy
--      ["We made sure noone followed us!"] = "", -- A_Classic_Fairytale:backstab
--      ["We need to move!"] = "", -- A_Classic_Fairytale:united
--      ["We need to prevent their arrival!"] = "", -- A_Classic_Fairytale:backstab
--      ["We need to warn the village."] = "", -- A_Classic_Fairytale:shadow
--      ["We should head back to the village now."] = "", -- A_Classic_Fairytale:shadow
--      ["We were trying to save her and we got lost."] = "", -- A_Classic_Fairytale:family
--      ["We won't let you hurt her!"] = "", -- A_Classic_Fairytale:journey
--      ["What?! A cannibal? Here? There is no time to waste! Come, you are prepared."] = "", -- A_Classic_Fairytale:first_blood
--      ["What a douche!"] = "", -- A_Classic_Fairytale:enemy
--      ["What am I gonna...eat, yo?"] = "", -- A_Classic_Fairytale:family
--      ["What are you doing at a distance so great, young one?"] = "", -- A_Classic_Fairytale:first_blood
--      ["What are you doing? Let her go!"] = "", -- A_Classic_Fairytale:journey
--      ["What a ride!"] = "", -- A_Classic_Fairytale:shadow
--      ["What a strange cave!"] = "", -- A_Classic_Fairytale:dragon
--      ["What a strange feeling!"] = "", -- A_Classic_Fairytale:backstab
--      ["What do my faulty eyes observe? A spy!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Whatever floats your boat..."] = "", -- A_Classic_Fairytale:shadow
--      [" What !! For all of this struggle i just win some ... TIME o0"] = "", -- portal
--      ["What has "] = "", -- A_Classic_Fairytale:backstab
--      ["What? Here? How did they find us?!"] = "", -- A_Classic_Fairytale:backstab
--      ["What is this place?"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy
--      ["What shall we do with the traitor?"] = "", -- A_Classic_Fairytale:backstab
--      ["WHAT?! You're the ones attacking us!"] = "", -- A_Classic_Fairytale:enemy
--      ["When?"] = "", -- A_Classic_Fairytale:enemy
--      ["When I find it..."] = "", -- A_Classic_Fairytale:dragon
--      ["Where are all these crates coming from?!"] = "", -- A_Classic_Fairytale:shadow
--      ["Where are they?!"] = "", -- A_Classic_Fairytale:backstab
--      ["Where did that alien run?"] = "", -- A_Classic_Fairytale:dragon
--      ["Where did you get the exploding apples?"] = "", -- A_Classic_Fairytale:shadow
--      ["Where did you get the exploding apples and the magic bow that shoots many arrows?"] = "", -- A_Classic_Fairytale:shadow
--      ["Where did you get the magic bow that shoots many arrows?"] = "", -- A_Classic_Fairytale:shadow
--      ["Where did you get the weapons in the forest, Dense Cloud?"] = "", -- A_Classic_Fairytale:backstab
--      ["Where do you get that?!"] = "", -- A_Classic_Fairytale:enemy
--      ["Where have you been?!"] = "", -- A_Classic_Fairytale:backstab
--      ["Where have you been?"] = "", -- A_Classic_Fairytale:united
--      ["? Why?"] = "", -- A_Classic_Fairytale:backstab
--      ["Why "] = "", -- A_Classic_Fairytale:backstab
--      ["! Why?!"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:united
--      ["Why are you doing this?"] = "", -- A_Classic_Fairytale:journey
--      ["Why are you helping us, uhm...?"] = "", -- A_Classic_Fairytale:family
--      ["Why can't he just let her go?!"] = "", -- A_Classic_Fairytale:family
--      ["Why do men keep hurting me?"] = "", -- A_Classic_Fairytale:first_blood
--      ["Why do you not like me?"] = "", -- A_Classic_Fairytale:shadow
--      ["Why do you want to take over our island?"] = "", -- A_Classic_Fairytale:enemy
--      ["Why me?!"] = "", -- A_Classic_Fairytale:backstab
--      ["Why would they do this?"] = "", -- A_Classic_Fairytale:backstab
--      ["- Will Get 1-3 random weapons"] = "", -- Continental_supplies
--      ["- Will refresh Parachute each turn."] = "", -- Continental_supplies
--      ["- Will refresh portalgun each turn."] = "", -- Continental_supplies
--      ["Will this ever end?"] = "",
--      ["WINNER IS "] = "", -- Mutant
--      ["WINNING TIME: "] = "",
--      ["Wise Oak"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
--      ["With Dense Cloud on the land of shadows, I'm the village's only hope..."] = "", -- A_Classic_Fairytale:journey
--      ["With the rest of the tribe gone, it was up to "] = "", -- A_Classic_Fairytale:dragon
--      ["Worry not, for it is a peaceful animal! There is no reason to be afraid..."] = "", -- A_Classic_Fairytale:first_blood
--      ["Wow, what a dream!"] = "", -- A_Classic_Fairytale:backstab
--      ["Y3K1337"] = "", -- A_Classic_Fairytale:journey, A_Classic_Fairytale:shadow
--      ["Yay, we won!"] = "", -- A_Classic_Fairytale:enemy
--      ["Y Chwiliad"] = "", -- A_Classic_Fairytale:dragon
--      ["Yeah...I think it's a 'he', lol."] = "", -- A_Classic_Fairytale:shadow
--      ["Yeah, sure! I died. Hillarious!"] = "", -- A_Classic_Fairytale:backstab
--      ["Yeah, take that!"] = "", -- A_Classic_Fairytale:dragon
--      ["Yeah? Watcha gonna do? Cry?"] = "", -- A_Classic_Fairytale:journey
--      ["Yes!"] = "", -- A_Classic_Fairytale:enemy
--      ["Yes, yeees! You are now ready to enter the real world!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Yo, dude, we're here, too!"] = "", -- A_Classic_Fairytale:family
--      ["You are given the chance to turn your life around..."] = "", -- A_Classic_Fairytale:shadow
--      ["You are playing with our lives here!"] = "", -- A_Classic_Fairytale:enemy
--      ["! You bastards!"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:united
--      ["You bear impressive skills, "] = "", -- A_Classic_Fairytale:dragon
--      ["You can't fire a portal on the blue surface"] = "", -- portal
--      ["You couldn't possibly believe that after refusing my offer I'd just let you go!"] = "", -- A_Classic_Fairytale:journey
--      ["You'd almost swear the water was rising!"] = "",
--      ["You'd better watch your steps..."] = "", -- A_Classic_Fairytale:journey
--      ["You did not make it in time, try again!"] = "", -- Basic_Training_-_Rope
--      ["You have 7 turns until the next wave arrives.|Make sure the arriving cannibals are greeted appropriately!|If the hog dies, the cause is lost.|Hint: you might want to use some mines..."] = "", -- A_Classic_Fairytale:backstab
--      ["You have "] = "", -- A_Classic_Fairytale:dragon
--      ["You have been giving us out to the enemy, haven't you!"] = "", -- A_Classic_Fairytale:backstab
--      ["You have been respawned, at your last checkpoint!"] = "", -- Basic_Training_-_Rope
--      ["You have been respawned, be more carefull next time!"] = "", -- Basic_Training_-_Rope
--      ["You have chosen the perfect moment to leave."] = "", -- A_Classic_Fairytale:united
--      ["You have failed to complete your task, young one!"] = "", -- A_Classic_Fairytale:journey
--      ["You have failed to save the tribe!"] = "", -- A_Classic_Fairytale:backstab
--      ["You have finally figured it out!"] = "", -- A_Classic_Fairytale:enemy
--      ["You have kidnapped our whole tribe!"] = "", -- A_Classic_Fairytale:enemy
--      ["You have killed an innocent hedgehog!"] = "", -- A_Classic_Fairytale:backstab
--      ["You have proven yourself worthy to see our most ancient secret!"] = "", -- A_Classic_Fairytale:first_blood
--      ["You have proven yourselves worthy!"] = "", -- A_Classic_Fairytale:enemy
--      ["You have SCORED!!"] = "",
--      ["You have to destroy 12 targets in 180 seconds"] = "", -- Basic_Training_-_Cluster_Bomb
--      ["You have won the game by proving true cooperative skills!"] = "", -- A_Classic_Fairytale:enemy
--      ["You just appeared out of thin air!"] = "", -- A_Classic_Fairytale:backstab
--      ["You just committed suicide..."] = "", -- A_Classic_Fairytale:shadow
--      ["You killed my father, you monster!"] = "", -- A_Classic_Fairytale:backstab
--      ["You know...taking a stroll."] = "", -- A_Classic_Fairytale:backstab
--      ["You know what? I don't even regret anything!"] = "", -- A_Classic_Fairytale:backstab
--      ["You'll see what I mean!"] = "", -- A_Classic_Fairytale:enemy
--      ["You may only attack from a rope!"] = "", -- WxW
--      ["You meatbags are pretty slow, you know!"] = "", -- A_Classic_Fairytale:enemy
--      ["You might want to find a way to instantly kill arriving cannibals!"] = "", -- A_Classic_Fairytale:backstab
--      ["Young one, you are telling us that they can instantly change location without a shaman?"] = "", -- A_Classic_Fairytale:united
--      ["You probably know what to do next..."] = "", -- A_Classic_Fairytale:first_blood
--      ["Your deaths will be avenged, cannibals!"] = "", -- A_Classic_Fairytale:enemy
--      ["Your death will not be in vain, Dense Cloud!"] = "", -- A_Classic_Fairytale:shadow
--      ["You're...alive!? But we saw you die!"] = "", -- A_Classic_Fairytale:backstab
--      ["You're a pathetic liar!"] = "", -- A_Classic_Fairytale:backstab
--      ["You're funny!"] = "", -- A_Classic_Fairytale:journey
--      ["You're getting pretty good! |Tip: When you shorten you rope you move faster! |and when you lengthen it you move slower"] = "", -- Basic_Training_-_Rope
--      ["You're pathetic! You are not worthy of my attention..."] = "", -- A_Classic_Fairytale:shadow
--      ["You're probably wondering why I bought you back..."] = "", -- A_Classic_Fairytale:backstab
--      ["You're terrorizing the forest...We won't catch anything like this!"] = "", -- A_Classic_Fairytale:shadow
--      ["Your hogs must survive!"] = "", -- A_Classic_Fairytale:journey
--      ["Your movement skills will be evaluated now."] = "", -- A_Classic_Fairytale:first_blood
--      ["You saved"] = "",
--      ["You've been assaulting us, we have been just defending ourselves!"] = "", -- A_Classic_Fairytale:enemy
--      ["You've failed. Try again."] = "",
	["You've reached the goal!| |Time: "] = "Você alcançou o objetivo!| |Tempo: ",
--      ["You will be avenged!"] = "", -- A_Classic_Fairytale:shadow
--      ["You won't believe what happened to me!"] = "", -- A_Classic_Fairytale:backstab
--      ["Yuck! I bet they'll keep worshipping her even after I save the village!"] = "", -- A_Classic_Fairytale:family
--      ["Zealandia"] = "", -- Continental_supplies
	["'Zooka Team"] = "Bazuqueiros",
--      ["Zork"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
    }
